/*  This file is part of libravatarserv.
 *  Copyright © 2022 tastytea <tastytea@tastytea.de>
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, version 3.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef LIBRAVATARSERV_HASH_HPP
#define LIBRAVATARSERV_HASH_HPP

#include "fs-compat.hpp"

#include <map>
#include <string>
#include <string_view>

namespace libravatarserv::hash {

enum class algorithm {
    SHA256,
    MD5
};

using table = std::map<std::string, std::string>;

// generate hash from text
[[nodiscard]] std::string generate_hash(algorithm algo, std::string_view text);

// generate hash -> email table
[[nodiscard]] table generate_table(algorithm algo, const fs::path &directory);

// return false if invalid characters are found in hash
[[nodiscard]] bool is_valid(std::string_view hash);

} // namespace libravatarserv::hash

#endif // LIBRAVATARSERV_HASH_HPP
